@@ -36,6 +36,12 @@ def clean_imports():
         sys.modules["fsspec"] = real_module
 
 
+def test_sorted_known_implementations():
+    expected = sorted(known_implementations.keys())
+    actual = list(known_implementations.keys())
+    assert actual == expected
+
+
 def test_registry_readonly():
     get_filesystem_class("file")
     assert "file" in registry
